@@ -53,10 +53,9 @@ exception Internal_error
   * joined across page boundaries allowing packets of arbitrary size. In practice
   * pages are usually around 4 kB.
   *)
-module Page :
-sig
+module Page : sig
   (** A page is a header and a body *)
-  type t = string*string
+  type t = string * string
 
   (** 
     * Returns the unique serial number for the logical bitstream of this page. 
@@ -117,24 +116,24 @@ sig
   (**
     * Checksums an ogg_page. *)
   val set_checksum : t -> unit
-
 end
 
-module Sync :
-sig
+module Sync : sig
   type t
 
+  (** Type for read functions. *)
+  type read = bytes -> int -> int -> int
+
   (** 
     * This function is used to initialize a [Sync.t] to a known initial value 
     * in preparation for manipulation of an Ogg bitstream. 
     *
-    * The function passed is used to fill the stream with new data. It receives a number of bytes to read
-    * and returns a string read and its size. *)
-  val create : (int -> string*int) -> t
+    * The function passed is used to fill the stream with new data. *)
+  val create : read -> t
 
   (**
     * Wrapper around [create] to open a file as the ogg stream. *)
-  val create_from_file : string -> (t*Unix.file_descr)
+  val create_from_file : string -> t * Unix.file_descr
 
   (** 
     * Read a page from [Sync.t] 
@@ -148,7 +147,7 @@ sig
     * [Sync.t] to initial values. 
     *
     * [read_func] is optional and is a new function to read new data. *)
-  val reset : ?read_func:(int -> string*int) -> t -> unit
+  val reset : ?read_func:read -> t -> unit
 
   (** 
     * This function synchronizes the ogg_sync_state struct to the next ogg_page.
@@ -159,9 +158,7 @@ sig
   val seek : t -> Page.t
 end
 
-
-module Stream :
-sig
+module Stream : sig
   (**
     * The [stream] values track the current encode/decode state of the
     * current logical bitstream.
@@ -201,6 +198,9 @@ sig
     * packet data meets/exceeds the maximum page size regardless of accumulated
     * packet count.
     *
+    * The exception [Not_enough_data] is raised if not enough data is available
+    * to generate the page.
+    *
     * Call [flush_page] if immediate  page generation is desired. This 
     * may be occasionally necessary, for example, to limit the temporal 
     * latency of a variable bitrate stream.
@@ -285,9 +285,7 @@ sig
   val packet_granulepos : packet -> Int64.t
 end
 
-module Skeleton : 
-sig
-
+module Skeleton : sig
   (**
     * Create an initial ogg skeleton packet ('fishead'),
     * to complete with data packet from the various codecs
@@ -297,10 +295,12 @@ sig
     ?presentation_numerator:Int64.t ->
     ?presentation_denominator:Int64.t ->
     ?basetime_numerator:Int64.t ->
-    ?basetime_denominator:Int64.t -> ?utc:Int32.t -> unit -> Stream.packet
+    ?basetime_denominator:Int64.t ->
+    ?utc:Int32.t ->
+    unit ->
+    Stream.packet
 
- (** Create an end-of-stream packet for
+  (** Create an end-of-stream packet for
    * an ogg skeleton logical stream *)
- val eos : unit -> Stream.packet
-
+  val eos : unit -> Stream.packet
 end
